.. HyperSpy User Guide documentation master file, created by
   sphinx-quickstart on Wed Feb 29 15:14:48 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

###########################
HyperSpy User Guide (DRAFT)
###########################

.. toctree::
    :maxdepth: 2

    intro.rst
    what_is_new.rst
    install.rst
    getting_started.rst
    tools.rst
    signal1d.rst
    signal2d.rst
    visualisation.rst
    mva.rst
    model.rst
    eels.rst
    eds.rst
    dielectric_function.rst
    io.rst
    metadata_structure.rst
    credits.rst
    bibliography.rst
